summaryrefslogtreecommitdiff
path: root/pcre_internal.h
diff options
context:
space:
mode:
authorph10 <ph10@2f5784b3-3f2a-0410-8824-cb99058d5e15>2013-10-06 18:33:56 +0000
committerph10 <ph10@2f5784b3-3f2a-0410-8824-cb99058d5e15>2013-10-06 18:33:56 +0000
commite0f44ec0903da7ad9c56eec0a0e5c8b02ce6ccb3 (patch)
treed7e548f203b80d44a5c7d9e07b19a1b04bafa328 /pcre_internal.h
parentc728cbfd976748abdf0511801e805ff0c846cdf2 (diff)
downloadpcre-e0f44ec0903da7ad9c56eec0a0e5c8b02ce6ccb3.tar.gz
Refactor named group handling for conditional tests.
git-svn-id: svn://vcs.exim.org/pcre/code/trunk@1365 2f5784b3-3f2a-0410-8824-cb99058d5e15
Diffstat (limited to 'pcre_internal.h')
-rw-r--r--pcre_internal.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/pcre_internal.h b/pcre_internal.h
index 4c8f501..9002f8f 100644
--- a/pcre_internal.h
+++ b/pcre_internal.h
@@ -2125,9 +2125,9 @@ enum {
/* The next two pairs must (respectively) be kept together. */
OP_CREF, /* 137 Used to hold a capture number as condition */
- OP_NCREF, /* 138 Same, but generated by a name reference*/
+ OP_DNCREF, /* 138 Used to point to duplicate names as a condition */
OP_RREF, /* 139 Used to hold a recursion number as condition */
- OP_NRREF, /* 140 Same, but generated by a name reference*/
+ OP_DNRREF, /* 140 Used to point to duplicate names as a condition */
OP_DEF, /* 141 The DEFINE condition */
OP_BRAZERO, /* 142 These two must remain together and in this */
@@ -2203,7 +2203,7 @@ some cases doesn't actually use these names at all). */
"Cond", \
"SBra", "SBraPos", "SCBra", "SCBraPos", \
"SCond", \
- "Cond ref", "Cond nref", "Cond rec", "Cond nrec", "Cond def", \
+ "Cond ref", "Cond dnref", "Cond rec", "Cond dnrec", "Cond def", \
"Brazero", "Braminzero", "Braposzero", \
"*MARK", "*PRUNE", "*PRUNE", "*SKIP", "*SKIP", \
"*THEN", "*THEN", "*COMMIT", "*FAIL", \
@@ -2290,8 +2290,8 @@ in UTF-8 mode. The code that uses this table must know about such things. */
1+LINK_SIZE+IMM2_SIZE, /* SCBRA */ \
1+LINK_SIZE+IMM2_SIZE, /* SCBRAPOS */ \
1+LINK_SIZE, /* SCOND */ \
- 1+IMM2_SIZE, 1+IMM2_SIZE, /* CREF, NCREF */ \
- 1+IMM2_SIZE, 1+IMM2_SIZE, /* RREF, NRREF */ \
+ 1+IMM2_SIZE, 1+2*IMM2_SIZE, /* CREF, DNCREF */ \
+ 1+IMM2_SIZE, 1+2*IMM2_SIZE, /* RREF, DNRREF */ \
1, /* DEF */ \
1, 1, 1, /* BRAZERO, BRAMINZERO, BRAPOSZERO */ \
3, 1, 3, /* MARK, PRUNE, PRUNE_ARG */ \
@@ -2300,8 +2300,7 @@ in UTF-8 mode. The code that uses this table must know about such things. */
1, 1, 1, 1, /* COMMIT, FAIL, ACCEPT, ASSERT_ACCEPT */ \
1+IMM2_SIZE, 1 /* CLOSE, SKIPZERO */
-/* A magic value for OP_RREF and OP_NRREF to indicate the "any recursion"
-condition. */
+/* A magic value for OP_RREF to indicate the "any recursion" condition. */
#define RREF_ANY 0xffff